@@ -368,7 +368,8 @@ def stan(file=None, model_name="anon_model", model_code=None, fit=None,
         m = StanModel(file=file, model_name=model_name, model_code=model_code,
                       boost_lib=boost_lib, eigen_lib=eigen_lib,
                       save_dso=save_dso, verbose=verbose)
-    fit = m.sampling(data, pars, chains, iter, warmup, thin, seed, init,
+    fit = m.sampling(data, pars=pars, chains=chains, iter=iter,
+                     warmup=warmup, thin=thin, seed=seed, init=init,
                      sample_file=sample_file, diagnostic_file=diagnostic_file,
                      verbose=verbose, algorithm=algorithm, control=control,
                      n_jobs=n_jobs, **kwargs)
