@@ -14,7 +14,7 @@ namespace stan {
       arg_refresh(): int_argument() {
         _name = "refresh";
         _description = "Number of interations between screen updates";
-        _validity = "0 < refresh";
+        _validity = "0 <= refresh";
         _default = "100";
         _default_value = 100;
         _constrained = true;
@@ -23,7 +23,7 @@ namespace stan {
         _value = _default_value;
       };
       
-      bool is_valid(int value) { return value > 0; }
+      bool is_valid(int value) { return value >= 0; }
       
     };
     
