@@ -495,13 +495,14 @@ namespace stan {
 
 
       factor_r.name("factor");
-      factor_r
-        =  int_literal_r     [_val = _1]
-        | double_literal_r    [_val = _1]
-        | fun_r(_r1)          [_val = set_fun_type_named_f(_1,_r1,_pass,boost::phoenix::ref(error_msgs_))]
+      factor_r =
+          fun_r(_r1)          [_val = set_fun_type_named_f(_1,_r1,_pass,
+                                                           boost::phoenix::ref(error_msgs_))]
         | variable_r          [_val = set_var_type_f(_1,boost::phoenix::ref(var_map_),
                                                      boost::phoenix::ref(error_msgs_),
                                                      _pass)]
+        | int_literal_r       [_val = _1]
+        | double_literal_r    [_val = _1]
         | ( lit('(') 
             > expression_g(_r1)    [_val = _1]
             > lit(')') )
