@@ -9,6 +9,7 @@
 #include <string>
 #include <vector>
 #include <boost/throw_exception.hpp>
+#include <boost/lexical_cast.hpp>
 #include <stan/math/matrix.hpp>
 #include <stan/io/var_context.hpp>
 
@@ -426,6 +427,7 @@ namespace stan {
      */
     class dump_reader {
     private:
+      std::string buf_;
       std::string name_;
       std::vector<int> stack_i_;
       std::vector<double> stack_r_;
@@ -494,6 +496,26 @@ namespace stan {
       }
 
 
+      bool scan_chars(const char *s, bool case_sensitive = true) {
+        for (size_t i = 0; s[i]; ++i) {
+          char c;
+          if (!(in_ >> c)) {
+            for (size_t j = 1; j < i; ++j) 
+              in_.putback(s[i-j]);
+            return false;
+          }
+          // all ASCII, so toupper is OK
+          if ((case_sensitive && c != s[i])
+              || (!case_sensitive && ::toupper(c) != ::toupper(s[i]))) {
+            in_.putback(c);
+            for (size_t j = 1; j < i; ++j) 
+              in_.putback(s[i-j]);
+            return false;
+          }
+        }
+        return true;
+      }
+
       bool scan_chars(std::string s, bool case_sensitive = true) {
         for (size_t i = 0; i < s.size(); ++i) {
           char c;
@@ -531,40 +553,44 @@ namespace stan {
 
         char c;
         bool is_double = false;
-        std::string buf;
+        buf_.clear();
         while (in_.get(c)) {
           if (std::isdigit(c)) { // before pre-scan || c == '-' || c == '+') {
-            buf.push_back(c);
+            buf_.push_back(c);
           } else if (c == '.'
                      || c == 'e'
                      || c == 'E'
                      || c == '-'
                      || c == '+') {
             is_double = true;
-            buf.push_back(c);
+            buf_.push_back(c);
           } else {
             in_.putback(c);
             break;
           }
         }
-        if (!is_double && stack_r_.size() == 0) {
-          int n;
-          if (!(std::stringstream(buf) >> n))
-            return false;
-          stack_i_.push_back(negate_val ? -n : n);
-          scan_optional_long();
-        } else {
-          for (size_t j = 0; j < stack_i_.size(); ++j)
-            stack_r_.push_back(static_cast<double>(stack_i_[j]));
-          // negate_val 
-          // ? -static_cast<double>(stack_i_[j])
-          // : static_cast<double>(stack_i_[j]));
-          stack_i_.clear();
-          double x;
-          if (!(std::stringstream(buf) >> x))
-            return false;
-          stack_r_.push_back(negate_val ? -x : x);
+        try {
+          if (!is_double && stack_r_.size() == 0) {
+            int n;
+            n = boost::lexical_cast<int>(buf_);
+            stack_i_.push_back(negate_val ? -n : n);
+            scan_optional_long();
+          } else {
+            for (size_t j = 0; j < stack_i_.size(); ++j)
+              stack_r_.push_back(static_cast<double>(stack_i_[j]));
+            // negate_val 
+            // ? -static_cast<double>(stack_i_[j])
+            // : static_cast<double>(stack_i_[j]));
+            stack_i_.clear();
+            double x;
+            x = boost::lexical_cast<double>(buf_);
+            stack_r_.push_back(negate_val ? -x : x);
+          }
         }
+        catch ( const boost::bad_lexical_cast &exc ) {
+          return false;
+        }
+
         return true;
       }
 
