@@ -1,7 +1,7 @@
 #ifndef __STAN__MATH__MATRIX__EIGEN_HPP__
 #define __STAN__MATH__MATRIX__EIGEN_HPP__
 
-#define EIGEN_DENSEBASE_PLUGIN "stan/math/matrix/EigenDenseBaseAddons.hpp"
+#define EIGEN_DENSEBASE_PLUGIN "stan/math/matrix/EigenDenseBaseAddons.h"
 #include <Eigen/Dense>
 #include <Eigen/QR>
 
