@@ -7,23 +7,12 @@
 #include <stan/agrad/rev.hpp>
 #include <stan/agrad/rev/matrix.hpp>
 #include <stan/math/error_handling.hpp>
-#include <stan/math/matrix/columns_dot_product.hpp>
-#include <stan/math/matrix/columns_dot_self.hpp>
-#include <stan/math/matrix/dot_product.hpp>
-#include <stan/math/matrix/dot_self.hpp>
 #include <stan/math/matrix_error_handling.hpp>
-#include <stan/math/matrix/ldlt.hpp>
-#include <stan/math/matrix/log.hpp>
-#include <stan/math/matrix/log_determinant.hpp>
-#include <stan/math/matrix/mdivide_left_spd.hpp>
-#include <stan/math/matrix/mdivide_left_tri_low.hpp>
-#include <stan/math/matrix/multiply.hpp>
-#include <stan/math/matrix/subtract.hpp>
-#include <stan/math/matrix/sum.hpp>
-#include <stan/math/matrix/trace_quad_form.hpp>
+#include <stan/math/matrix/log_determinant_ldlt.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/prob/constants.hpp>
 #include <stan/prob/traits.hpp>
+#include <stan/math/error_handling/matrix/check_ldlt_factor.hpp>
 
 namespace stan {
 
@@ -41,12 +30,9 @@ namespace stan {
       using stan::math::check_not_nan;
       using stan::math::check_size_match;
       using stan::math::check_positive;
-      using stan::math::check_pos_definite;
       using stan::math::check_finite;
       using stan::math::check_symmetric;
-      using stan::math::dot_product;
-      using stan::math::mdivide_left_spd;
-      using stan::math::log_determinant;
+      using stan::math::check_ldlt_factor;
       
       if (!check_size_match(function, 
                             Sigma.rows(), "Rows of covariance parameter",
@@ -57,8 +43,11 @@ namespace stan {
         return lp;
       if (!check_symmetric(function, Sigma, "Covariance matrix", &lp))
         return lp;
-      if (!check_pos_definite(function, Sigma, "Covariance matrix", &lp))
+      
+      stan::math::LDLT_factor<T_covar,Eigen::Dynamic,Eigen::Dynamic> ldlt_Sigma(Sigma);
+      if(!check_ldlt_factor(function,ldlt_Sigma,"LDLT_Factor of covariance parameter",&lp))
         return lp;
+
       if (!check_size_match(function, 
                             y.size(), "Size of random variable",
                             mu.size(), "size of location parameter",
@@ -86,7 +75,7 @@ namespace stan {
         lp += NEG_LOG_SQRT_TWO_PI * y.rows();
       
       if (include_summand<propto,T_covar>::value) {
-        lp -= 0.5 * log_determinant(Sigma);
+        lp -= 0.5 * log_determinant_ldlt(ldlt_Sigma);
       }
 
       if (include_summand<propto,T_y,T_loc,T_covar>::value) {
@@ -95,10 +84,7 @@ namespace stan {
             Eigen::Dynamic, 1> y_minus_mu(y.size());
         for (int i = 0; i < y.size(); i++)
           y_minus_mu(i) = y(i)-mu(i);
-        Eigen::Matrix<typename 
-            boost::math::tools::promote_args<T_covar,T_loc,T_y>::type,
-            Eigen::Dynamic, 1> Sinv_y_minus_mu(mdivide_left_spd(Sigma,y_minus_mu));
-        lp -= 0.5 * dot_product(y_minus_mu,Sinv_y_minus_mu);
+        lp -= 0.5 * trace_inv_quad_form_ldlt(ldlt_Sigma,y_minus_mu);
       }
       return lp;
     }
@@ -126,14 +112,10 @@ namespace stan {
       
       using stan::math::check_size_match;
       using stan::math::check_positive;
-      using stan::math::check_pos_definite;
       using stan::math::check_finite;
       using stan::math::check_symmetric;
       using stan::math::check_not_nan;
-      using stan::math::sum;
-      using stan::math::mdivide_left_spd;
-      using stan::math::log_determinant;
-      using stan::math::columns_dot_product;
+      using stan::math::check_ldlt_factor;
       
       if (!check_size_match(function, 
                             Sigma.rows(), "Rows of covariance matrix",
@@ -144,8 +126,11 @@ namespace stan {
         return lp;
       if (!check_symmetric(function, Sigma, "Covariance matrix", &lp))
         return lp;
-      if (!check_pos_definite(function, Sigma, "Covariance matrix", &lp))
+
+      stan::math::LDLT_factor<T_covar,Eigen::Dynamic,Eigen::Dynamic> ldlt_Sigma(Sigma);
+      if(!check_ldlt_factor(function,ldlt_Sigma,"LDLT_Factor of Sigma",&lp))
         return lp;
+
       if (!check_size_match(function, 
                             y.cols(), "Columns of random variable",
                             mu.rows(), "rows of location parameter",
@@ -173,7 +158,7 @@ namespace stan {
         lp += NEG_LOG_SQRT_TWO_PI * y.cols() * y.rows();
       
       if (include_summand<propto,T_covar>::value) {
-        lp -= 0.5 * log_determinant(Sigma) * y.rows();
+        lp -= 0.5 * log_determinant_ldlt(ldlt_Sigma) * y.rows();
       }
       
       if (include_summand<propto,T_y,T_loc,T_covar>::value) {
@@ -194,17 +179,12 @@ namespace stan {
             boost::math::tools::promote_args<T_loc,T_y>::type,
             Eigen::Dynamic,Eigen::Dynamic> z(y_minus_MU.transpose()); // was = 
         
-        // FIXME: revert this code when subtract() is fixed.
         // Eigen::Matrix<typename 
         //               boost::math::tools::promote_args<T_loc,T_y>::type,
         //               Eigen::Dynamic,Eigen::Dynamic> 
         //   z(subtract(y,MU).transpose()); // was = 
         
-        Eigen::Matrix<typename 
-            boost::math::tools::promote_args<T_covar,T_loc,T_y>::type,
-            Eigen::Dynamic,Eigen::Dynamic> Sinv_z(mdivide_left_spd(Sigma,z));
-        
-        lp -= 0.5 * sum(columns_dot_product(z,Sinv_z));
+        lp -= 0.5 * trace_inv_quad_form_ldlt(ldlt_Sigma,z);
       }
       return lp;      
     }
