@@ -4,8 +4,10 @@
 #include <boost/random/chi_squared_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
 
-#include <stan/agrad.hpp>
+#include <stan/agrad/partials_vari.hpp>
 #include <stan/math/error_handling.hpp>
+#include <stan/math/constants.hpp>
+#include <stan/math/functions/multiply_log.hpp>
 #include <stan/math/functions/value_of.hpp>
 #include <stan/meta/traits.hpp>
 #include <stan/prob/constants.hpp>
@@ -176,10 +178,6 @@ namespace stan {
           
       agrad::OperandsAndPartials<T_y, T_dof> operands_and_partials(y, nu);
           
-      std::fill(operands_and_partials.all_partials,
-                operands_and_partials.all_partials 
-                + operands_and_partials.nvaris, 0.0);
-        
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
 
@@ -288,10 +286,6 @@ namespace stan {
           
       agrad::OperandsAndPartials<T_y, T_dof> operands_and_partials(y, nu);
           
-      std::fill(operands_and_partials.all_partials,
-                operands_and_partials.all_partials 
-                + operands_and_partials.nvaris, 0.0);
-        
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
 
@@ -392,10 +386,6 @@ namespace stan {
           
       agrad::OperandsAndPartials<T_y, T_dof> operands_and_partials(y, nu);
           
-      std::fill(operands_and_partials.all_partials,
-                operands_and_partials.all_partials 
-                + operands_and_partials.nvaris, 0.0);
-        
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
 
